==> react-form-builder-1.9.0.tgz: package/lib/InlineButton/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { field } from '../prop-types';
import MoleculeButtonGroup from '@s-ui/react-molecule-button-group';
import Button from '@s-ui/react-atom-button';

var InlineButton = function InlineButton(_ref) {
  var inlineButton = _ref.inlineButton,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors;
  var errorMessages = errors[inlineButton.id];

  var onClickHandler = function onClickHandler(value) {
    return onChange(inlineButton.id, value);
  };

  var inlineButtonProps = _objectSpread({
    id: inlineButton.id,
    label: inlineButton.label,
    tabIndex: tabIndex
  }, inlineButton.disabled && {
    disabled: true
  }, {}, inlineButton.hidden && {
    hidden: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  });

  if (inlineButtonProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-InlineButton sui-FormBuilder-" + (inlineButtonProps.id || tabIndex)
  }, React.createElement(MoleculeButtonGroup, null, inlineButton === null || inlineButton === void 0 ? void 0 : inlineButton.datalist.map(function (button) {
    return React.createElement(Button, {
      key: button.text,
      design: button.value === inlineButton.value ? 'solid' : 'outline',
      onClick: function onClick() {
        return onClickHandler(button.value);
      },
      isSubmit: false,
      isButton: true
    }, button.text);
  })));
};

InlineButton.displayName = 'InlineButton';
export default InlineButton;

==> react-form-builder-1.11.0.tgz: package/lib/InlineButton/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeButtonGroup from '@s-ui/react-molecule-button-group';
import Button from '@s-ui/react-atom-button';

var InlineButton = function InlineButton(_ref) {
  var inlineButton = _ref.inlineButton,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors;
  var errorMessages = errors[inlineButton.id];

  var onClickHandler = function onClickHandler(value) {
    return onChange(inlineButton.id, value);
  };

  var inlineButtonProps = _objectSpread({
    id: inlineButton.id,
    label: inlineButton.label,
    tabIndex: tabIndex
  }, inlineButton.disabled && {
    disabled: true
  }, {}, inlineButton.hidden && {
    hidden: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  });

  if (inlineButtonProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-InlineButton sui-FormBuilder-" + (inlineButtonProps.id || tabIndex)
  }, React.createElement(MoleculeButtonGroup, null, inlineButton === null || inlineButton === void 0 ? void 0 : inlineButton.datalist.map(function (button) {
    return React.createElement(Button, {
      key: button.text,
      design: button.value === inlineButton.value ? 'solid' : 'outline',
      onClick: function onClick() {
        return onClickHandler(button.value);
      },
      isSubmit: false,
      isButton: true
    }, button.text);
  })));
};

InlineButton.displayName = 'InlineButton';
export default React.memo(InlineButton, createComponentMemo('inlineButton'));
